# nnterp

This might become a real package at some point, for now it's just a package in which I dump my nnsight code.

nnsight_utils.py basically allows you to deal with TL and HF models in a similar way.

interventions.py is a module that contains tools like logit lens, patchscope lens and other interventions.
